@@ -13,6 +13,7 @@ from ..services.user import UserService
 from ..services.workflow import WorkflowService
 from ..services.files import FileOperationService
 from ..services.webhook import WebhookService
+from ..services.vendor import VendorService
 
 
 class CodeMieClient:
@@ -89,6 +90,9 @@ class CodeMieClient:
         self.webhook = WebhookService(
             self._api_domain, self._token, verify_ssl=self._verify_ssl
         )
+        self.vendors = VendorService(
+            self._api_domain, self._token, verify_ssl=self._verify_ssl
+        )
 
     @property
     def token(self) -> str:
@@ -135,4 +139,7 @@ class CodeMieClient:
         self.conversations = ConversationService(
             self._api_domain, self._token, verify_ssl=self._verify_ssl
         )
+        self.vendors = VendorService(
+            self._api_domain, self._token, verify_ssl=self._verify_ssl
+        )
         return self._token
